@@ -1,7 +1,7 @@
 package App::BashHistoryUtils;
 
-our $DATE = '2015-11-04'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-11-05'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -71,34 +71,44 @@ sub _do {
         }
     }
 
-    local @ARGV = ($histfile);
     my $now = time;
+
+    my $code;
+    if ($which eq 'each') {
+        $code = eval "package main; no strict; sub { $args{code} }";
+        die if $@;
+    } else {
+        $code = sub {
+            if (defined($args{max_age}) &&
+                    $main::TS < $now-$args{max_age}) {
+                $main::PRINT = 0;
+            }
+            if (defined($args{min_age}) &&
+                    $main::TS > $now-$args{min_age}) {
+                $main::PRINT = 0;
+            }
+            if ($pat && $_ =~ $pat) {
+                $main::PRINT = 0;
+            }
+
+            if ($which eq 'grep') {
+                $main::PRINT = !$main::PRINT;
+            }
+            if ($args{invert_match}) {
+                $main::PRINT = !$main::PRINT;
+            }
+        };
+    }
+
+    local @ARGV = ($histfile);
     my $stdout = Capture::Tiny::capture_stdout(
         sub {
-            Bash::History::Read::each_hist(
-                sub {
-                    if (defined($args{max_age}) &&
-                            $main::TS < $now-$args{max_age}) {
-                        $main::PRINT = 0;
-                    }
-                    if (defined($args{min_age}) &&
-                            $main::TS > $now-$args{min_age}) {
-                        $main::PRINT = 0;
-                    }
-                    if ($pat && $_ =~ $pat) {
-                        $main::PRINT = 0;
-                    }
-
-                    if ($which eq 'grep') {
-                        $main::PRINT = !$main::PRINT;
-                    }
-                    if ($args{invert_match}) {
-                        $main::PRINT = !$main::PRINT;
-                    }
-                });
-        });
+            Bash::History::Read::each_hist($code);
+        }
+    );
 
     if ($which eq 'grep' ||
+            $which eq 'each' ||
             $which eq 'delete' && $args{-dry_run}) {
         return [200,"OK", $stdout, {'cmdline.skip_format'=>1}];
     } elsif ($which eq 'delete') {
@@ -146,6 +156,34 @@ sub delete_bash_history_entries {
     _do('delete', @_);
 }
 
+{
+    my $spec = {
+        v => 1.1,
+        summary => 'Run Perl code for each bash history entry',
+        args => {
+            %arg_histfile,
+            %args_filtering,
+            code => {
+                summary => 'Perl code to run for each entry',
+                description => <<'_',
+
+Inside the code, you can set `$PRINT` to 0 to suppress the output of the entry.
+You can modify `$_` to modify the entry. `$TS` (timestamp) is also available.
+
+_
+                schema => 'str*',
+                req => 1,
+                pos => 0,
+            },
+        },
+    };
+    delete $spec->{args}{pattern};
+    $SPEC{each_bash_history_entry} = $spec;
+}
+sub each_bash_history_entry {
+    _do('each', @_);
+}
+
 1;
 # ABSTRACT: CLI utilities related to bash history file
 
@@ -161,7 +199,7 @@ App::BashHistoryUtils - CLI utilities related to bash history file
 
 =head1 VERSION
 
-This document describes version 0.01 of App::BashHistoryUtils (from Perl distribution App-BashHistoryUtils), released on 2015-11-04.
+This document describes version 0.02 of App::BashHistoryUtils (from Perl distribution App-BashHistoryUtils), released on 2015-11-05.
 
 =head1 DESCRIPTION
 
@@ -171,6 +209,8 @@ This distribution includes the following CLI utilities:
 
 =item * L<delete-bash-history-entries>
 
+=item * L<each-bash-history-entry>
+
 =item * L<grep-bash-history-entries>
 
 =back
@@ -233,6 +273,51 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 each_bash_history_entry(%args) -> [status, msg, result, meta]
+
+Run Perl code for each bash history entry.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<code>* => I<str>
+
+Perl code to run for each entry.
+
+Inside the code, you can set C<$PRINT> to 0 to suppress the output of the entry.
+You can modify C<$_> to modify the entry. C<$TS> (timestamp) is also available.
+
+=item * B<histfile> => I<str> (default: "/home/s1/.bash_history")
+
+=item * B<ignore_case> => I<bool>
+
+=item * B<invert_match> => I<bool>
+
+=item * B<max_age> => I<duration>
+
+Match entries older than a certain age.
+
+=item * B<min_age> => I<duration>
+
+Match entries younger than a certain age.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 grep_bash_history_entries(%args) -> [status, msg, result, meta]
 
 Show matching entries from bash history file.
